@@ -1,6 +1,6 @@
 see.lnorm.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     mu <- 0
@@ -26,7 +26,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Log-normal Distribution")
+    tkwm.title(m, "LNORM(\u03bc, \u03c3\u00B2)")
     tkpack(tklabel(m,text="      Visualizing the Log-normal Distribution      "))
     tkwm.geometry(m, "+0+0")
     
@@ -65,7 +65,7 @@ require(tcltk) || stop("tcltk support is absent")
 
 
 see.lnormcdf.tck<-function (){ 
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     mu <- 0
@@ -77,7 +77,7 @@ require(tcltk) || stop("tcltk support is absent")
     xmax <- 15
     assign("xmax", tclVar(xmax), envir= slider.env)
            
-   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
         mu <- as.numeric(evalq(tclvalue(mu), envir= slider.env))
         sigma <- as.numeric(evalq(tclvalue(sigma), envir= slider.env))
@@ -94,7 +94,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Log-normal Distribution")
+    tkwm.title(m, "LNORM(\u03bc, \u03c3\u00B2)")
     tkpack(tklabel(m,text="      Visualizing the Log-normal Distribution      "))
     tkwm.geometry(m, "+0+0")
     
